Learn R Programming

colorblindcheck (version 1.0.4)

colorblindcheck-package: colorblindcheck: Check Color Palettes for Problems with Color Vision Deficiency

Description

logo

Compare color palettes with simulations of color vision deficiencies - deuteranopia, protanopia, and tritanopia. It includes calculation of distances between colors, and creating summaries of differences between a color palette and simulations of color vision deficiencies. This work was inspired by the blog post at https://www.datawrapper.de/blog/colorblind-check.

Arguments

Author

Maintainer: Jakub Nowosad nowosad.jakub@gmail.com (ORCID)

See Also